<?php
/**
 * A general deck structure class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseDeckStructure extends BaseStructure {
	// Anzahl Decks
	private $numDecks = 0;

	// Konstruktor
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);

		// Set description
		$this->setObjectDescription("Deckstruktur");
	}

	// Deckstruktur dem Schiff hinzufuegen
	public function addShipPartToShip (ConstructableShip $shipInstance, ConstructableShipPart $deckInstance) {
		if ((defined('DEBUG_STRUCTURE')) || (defined('DEBUG_ALL'))) $this->getDebugInstance()->output(sprintf("[%s:%d] Das Deck <strong>%s</strong> wird f&uuml;r das Schiff <strong>%s</strong> konstruiert.",
			__CLASS__,
			__LINE__,
			$deckInstance->getObjectDescription(),
			$shipInstance->getShipName()
		));

		// Eltern-Methode aufrufen
		parent::addShipPartToShip($shipInstance, $deckInstance);

		// Andere Daten uebertragen und von der Quelle loeschen
		$this->setNumDecks($deckInstance->getNumDecks());
		$deckInstance->removeNumDecks();

		if ((defined('DEBUG_STRUCTURE')) || (defined('DEBUG_ALL'))) $this->getDebugInstance()->output(sprintf("[%s:%d] Das Deck <strong>%s</strong> wurde in das Schiff <strong>%s</strong> eingebaut.",
			__CLASS__,
			__LINE__,
			$deckInstance->getObjectDescription(),
			$shipInstance->getShipName()
		));
	}

	// Deckanzahl entfernen
	public final function removeNumDecks() {
		unset($this->numDecks);
	}

	// Setter-Methode fuer Anzahl Decks
	public final function setNumDecks($numDecks) {
		$this->numDecks = (int) $numDecks;
	}

	// Getter-Methode fuer Anzahl Decks
	public final function getNumDecks() {
		return $this->numDecks;
	}
}

// [EOF]
?>
