<?php
/**
 * A helper for web links
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebLinkHelper extends BaseWebHelper implements HelpableTemplate {
	/**
	 * Name of the link
	 */
	private $linkName = "";

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set part description
		$this->setObjectDescription("A helper for generating web links");
	}

	/**
	 * Creates the helper class
	 *
	 * @param	$templateInstance	An instance of a template engine
	 * @param	$linkName			Name of the link we shall generate
	 * @return	$helperInstance		A prepared instance of this helper
	 */
	public final static function createWebLinkHelper (CompileableTemplate $templateInstance, $linkName) {
		// Get new instance
		$helperInstance = new WebLinkHelper();

		// Set template instance
		$helperInstance->setTemplateInstance($templateInstance);

		// Set Link name
		$helperInstance->setLinkName($linkName);

		// Return the prepared instance
		return $helperInstance;
	}

	/**
	 * Setter for link name
	 *
	 * @param	$linkName	Name of the link we shall generate
	 * @return	void
	 */
	protected final function setLinkName ($linkName) {
		$this->linkName = (string) $linkName;
	}

	/**
	 * Getter for link name
	 *
	 * @return	$linkName	Name of the link we shall generate
	 */
	public final function getLinkName () {
		return $this->linkName;
	}

	/**
	 * Flush the content out,e g. to a template variable
	 *
	 * @return	void
	 */
	public function flushContent () {
		$this->partialStub("Please implement this method.");
	}
}

// [EOF]
?>
